<?php

Class FirmModel extends CI_Model
{
    function __construct()
    {
        parent::__construct();
    }

    /*****************************************************************************/
    /*                                  FIRM                                     */
    /*****************************************************************************/
    public function insert($data)
    {
        $this->db->insert('firm', $data);
        if ($this->db->affected_rows() > 0) {
            return $this->db->insert_id();
        }
        return 0;
    }

    function delete($id)
    {
        $this->db->where('id', $id);
        $this->db->delete('firm');
    }

    function update($data, $id)
    {
        $this->db->where('id', $id);
        $this->db->update('firm', $data);
    }


    public function getFirms()
    {
        $this->db->select('*');
        $this->db->from('firm');
        $query = $this->db->get();
        return $query->result();
    }

    public function getHeadOffice()
    {
        $this->db->select('firm.*, firm_branch.address as bAddress,
         firm_branch.id as bID,
         firm_branch.town as bTown,
         firm_branch.county as bCounty,
         firm_branch.postcode as bPC,
         entries_made.town as eTown');
        $this->db->from('firm');
        $this->db->join('firm_branch', 'firm.id = firm_branch.firm');
        $this->db->join('entries_made', 'entries_made.id = firm_branch.town');
        $this->db->where('firm_branch.head_office', '1');
        $query = $this->db->get();
        return $query->result();
    }

    public function getAll()
    {
        $this->db->select('firm.*, firm_branch.address as bAddress,
         firm_branch.id as bID,
         firm_branch.town as bTown,
         firm_branch.county as bCounty,
         firm_branch.postcode as bPC');
        $this->db->from('firm');
        $this->db->join('firm_branch', 'firm.id = firm_branch.firm');
        $this->db->order_by('firm.name', 'asc');
        $query = $this->db->get();
        return $query->result();
    }


    function getById($id)
    {
        $query = $this->db->select('*')
            ->get_where('firm', array('id' => $id))
            ->row();
        return $query;
    }

    function count()
    {
        $query = $this->db->select("count(id) AS Total")
            ->from('firm')
            ->get()
            ->row();

        return $query;

    }


    /*****************************************************************************/
    /*                                  FIRM BRANCH                              */
    /*****************************************************************************/
    public function insertBranch($data)
    {
        $this->db->insert('firm_branch', $data);
        if ($this->db->affected_rows() > 0) {
            return $this->db->insert_id();
        }
        return 0;
    }

    function updateBranch($data, $id)
    {
        $this->db->where('id', $id);
        $this->db->update('firm_branch', $data);
    }

    function deleteBranchByFirm($id)
    {
        $this->db->where('firm', $id);
        $this->db->delete('firm_branch');
    }

    function deleteBranch($id)
    {
        $this->db->where('id', $id);
        $this->db->delete('firm_branch');
    }

    public function getBranches()
    {
        $this->db->select('firm.*, firm_branch.address as bAddress,
         firm_branch.id as bID,
         firm_branch.town as bTown,
         firm_branch.county as bCounty,
         firm_branch.postcode as bPC,
         entries_made.town as eTown');
        $this->db->from('firm');
        $this->db->join('firm_branch', 'firm.id = firm_branch.firm');
        $this->db->join('entries_made', 'entries_made.id = firm_branch.town');
        $this->db->where('firm_branch.head_office', '0');
        $query = $this->db->get();
        return $query->result();
    }

}

?>