<?php

Class SolicitorModel extends CI_Model
{
    function __construct()
    {
        parent::__construct();
    }

    /*****************************************************************************/
    /*                                  Scolicitor                               */
    /*****************************************************************************/
    public function insert($data)
    {
        $this->db->insert('scolicitor', $data);
        if ($this->db->affected_rows() > 0) {
            return $this->db->insert_id();
        }
        return 0;
    }

    function delete($id)
    {
        $this->db->where('id', $id);
        $this->db->delete('scolicitor');
    }

    function update($data, $id)
    {
        $this->db->where('id', $id);
        $this->db->update('scolicitor', $data);
    }


    public function getAll()
    {
        $this->db->select('scolicitor.*, firm.name as name,  firm_branch.address as bAddress,
         firm_branch.id as bID,
         firm_branch.town as bTown,
         firm_branch.county as bCounty,
         firm_branch.postcode as bPC');
        $this->db->from('scolicitor');
        $this->db->join('firm_branch', 'firm_branch.id = scolicitor.firm');
        $this->db->join('firm', 'firm.id = firm_branch.firm');
        $query = $this->db->get();
        return $query->result();
    }

    function getById($id)
    {
        $query = $this->db->select('*')
            ->get_where('scolicitor', array('id' => $id))
            ->row();
        return $query;
    }

    function getSRN($SRN)
    {
        $query = $this->db->query("SELECT EXISTS ( SELECT id FROM scolicitor WHERE srn =  ".$SRN." ) AS srnCH");
        return $query->row();
    }

    function count()
    {
        $query = $this->db->select("count(id) AS Total")
            ->from('scolicitor')
            ->get()
            ->row();

        return $query;

    }

    /*****************************************************************************/
    /*                                  SEARCH                                   */
    /*****************************************************************************/
    public function getSearch($GenLitigation, $ComLitigation, $Debt, $Defam, $Emp, $Inhouse, $Family, $Banking, $DebtRec, $Insurance,
                              $position, $num1, $num2)
    {
        $this->db->select('scolicitor.*,
         firm.name,
         firm.website,
         firm.solicitors_num,
         firm_branch.address as bAddress,
         firm_branch.id as bID,
         firm_branch.town as bTown,
         firm_branch.county as bCounty,
         firm_branch.postcode as bPC,
         entries_made.town as eTown');
        $this->db->from('scolicitor');
        $this->db->join('firm_branch', 'firm_branch.id = scolicitor.firm');
        $this->db->join('entries_made', 'entries_made.id = firm_branch.town');
        $this->db->join('firm', 'firm.id = firm_branch.firm');
        if ($GenLitigation) {
            $this->db->or_where('scolicitor.general_litigation', $GenLitigation);
        }
        if ($ComLitigation) {
            $this->db->or_where('scolicitor.commercial_litigation', $ComLitigation);
        }
        if ($Debt) {
            $this->db->or_where('scolicitor.debt_bankruptcy', $Debt);
        }
        if ($Defam) {
            $this->db->or_where('scolicitor.defamation', $Defam);
        }
        if ($Emp) {
            $this->db->or_where('scolicitor.employment_law', $Emp);
        }
        if ($Inhouse) {
            $this->db->or_where('scolicitor.in_house_lawyer', $Inhouse);
        }
        if ($Family) {
            $this->db->or_where('scolicitor.family_law', $Family);
        }
        if ($Banking) {
            $this->db->or_where('scolicitor.banking', $Banking);
        }
        if ($DebtRec) {
            $this->db->or_where('scolicitor.debt_recovery', $DebtRec);
        }
        if ($Insurance) {
            $this->db->or_where('scolicitor.insurance', $Insurance);
        }
        if ($position) {
            $this->db->or_where('scolicitor.position', $position);
        }
        if ($num1) {
            $this->db->where('firm.solicitors_num >= ', $num1);
            $this->db->where('firm.solicitors_num <= ', $num2);
        }
        $this->db->where('scolicitor.exported', 0);
        $query = $this->db->get();
        return $query->result();
    }

    public function getTempSearch()
    {
        $this->db->select('*');
        $this->db->from('temp_search');
        $query = $this->db->get();
        return $query->result();
    }


    public function insertTempSearch($data)
    {
        $this->db->insert('temp_search', $data);
    }

    public function deleteTempSearch()
    {
        $this->db->truncate('temp_search');
    }


    /*****************************************************************************/
    /*                                  HISTORY                                  */
    /*****************************************************************************/

    public function getExportHistory__()
    {
        $query = $this->db->query('SELECT date, GROUP_CONCAT(concat(scolicitor.surname, " ", scolicitor.firstname) SEPARATOR "\n") as names
FROM scolicitor_export
LEFT JOIN scolicitor ON (scolicitor.id = scolicitor_export.scolicitor)
GROUP BY date(date)');
        return $query->result();
    }

    public function getExportHistoryDate()
    {
        $query = $this->db->query('SELECT DISTINCT(DATE(date))  as date FROM scolicitor_export');
        return $query->result();
    }

    public function getExportHistory($date)
    {
        $query = $this->db->query("SELECT scolicitor_export.date, scolicitor_export.scolicitor as ID,
             CONCAT(scolicitor.firstname, ' ' , scolicitor.surname) as Sname,
             firm.name as Fname,
             srn,
             scolicitor.general_litigation as cat1,
             scolicitor.commercial_litigation as cat2,
             scolicitor.debt_bankruptcy as cat3,
             scolicitor.defamation as cat4,
             scolicitor.employment_law as cat5,
             scolicitor.in_house_lawyer as cat6,
             scolicitor.family_law as cat7,
             scolicitor.banking as cat8,
             scolicitor.debt_recovery as cat9,
             scolicitor.insurance as cat10
            FROM scolicitor_export
            LEFT JOIN scolicitor ON (scolicitor.id = scolicitor_export.scolicitor)
            LEFT JOIN firm_branch ON (scolicitor.firm = firm_branch.id)
            LEFT JOIN firm ON (firm.id = firm_branch.firm)
            WHERE scolicitor_export.archive = 0 AND DATE(scolicitor_export.date) = '".$date."'");
        return $query->result();
    }

    public function insertExport($data)
    {
        $this->db->insert('scolicitor_export', $data);
    }


    function deleteExport($id)
    {
        $this->db->where('DATE(date)', $id);
        $this->db->delete('scolicitor_export');
    }

    function archiveExport($data, $id)
    {
        $this->db->where('DATE(date)', $id);
        $this->db->update('scolicitor_export', $data);
    }



    /*****************************************************************************/
    /*                                  SETTING                                  */
    /*****************************************************************************/
    function resetAllExportTicks($data)
    {
        $this->db->update('scolicitor', $data);
    }

    function truncateExport()
    {
        $this->db->truncate('scolicitor_export');
    }

}

?>